<?php
require ("template-7.2d.inc.php");
$tpl = new Template();
$tpl->set_file ("tp", "foobar.ihtml");
$tpl->set_block("tp", "foo", "foo_parsed");
$tpl->set_block("foo", "bar", "bar_parsed");
for ($i = 0; $i < 2; $i++) {
	$tpl->set_var("bar_parsed", ""); // to reset the bar container
	$tpl->set_var(array("aaa" => $i));
	for ($j = 0; $j < 10; $j++) {
/* **************************************************** */
		if ($j != 5)
/* **************************************************** */
		{
		$tpl->set_var(array("bbb" => $j));
		$tpl->parse("bar_parsed", "bar", true);
		}
	}
	$tpl->parse("foo_parsed", "foo", true);
}
$tpl->pparse("out", "tp");
?>
